#!/usr/bin/env python

'''
hash.py (c) 2013 Perry Harrington

This program will generate a HMAC-SHA256 signature for a Propeller 2 bootloader binary.

This only prints the ASCII hex version of the digest, the routine actually returns the
binary version of the signature.

This program is released under the MIT license.

'''

import hashlib
import hmac
from binascii import hexlify,unhexlify

def SignPayload(key,filename):

    binkey = unhexlify(key)

    with open(filename, "rb") as f:
        msg = f.read()
        digest = hmac.new(binkey,msg,hashlib.sha256)
        return digest.digest()


def main():
    from optparse import OptionParser
    
    usage = "usage: %prog [options] arg"
    parser = OptionParser(usage)
    parser.add_option("-f", "--file", dest="filename", help="calculate HMAC hash of FILE", metavar="FILE", default="payload")
    parser.add_option("-k", "--key", dest="key", help="hex string of key to sign with", metavar="KEY", default="15670d6f18a696c0368f6c01ee8236c0")
    
    (options, args) = parser.parse_args()
             
    print hexlify(SignPayload(options.key,options.filename))

if __name__ == "__main__":
    main()